@@ -1,21 +1,8 @@
 /*
-    Copyright (c) 2001-2003 Cornelius Schumacher <schumacher@kde.org>
-    Copyright (c) 2004 Reinhold Kainhofer <reinhold@kainhofer.com>
+    SPDX-FileCopyrightText: 2001-2003 Cornelius Schumacher <schumacher@kde.org>
+    SPDX-FileCopyrightText: 2004 Reinhold Kainhofer <reinhold@kainhofer.com>
 
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Library General Public
-    License as published by the Free Software Foundation; either
-    version 2 of the License, or (at your option) any later version.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Library General Public License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-    Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 /**
   @file
@@ -33,8 +20,8 @@
 #ifndef KTNEF_FORMATTER_H
 #define KTNEF_FORMATTER_H
 
+#include <KCalendarCore/MemoryCalendar>
 #include <QString>
-#include <kcalendarcore/memorycalendar.h>
 
 #include "ktnef_export.h"
 
@@ -45,7 +32,6 @@ class InvitationFormatterHelper;
 
 namespace KTnef
 {
-
 /**
     Formats a @acronym TNEF attachment to an HTML mail.
 
@@ -54,8 +40,8 @@ namespace KTnef
     @param h is a pointer to a InvitationFormatterHelp object.
   */
 Q_REQUIRED_RESULT KTNEF_EXPORT QString formatTNEFInvitation(const QByteArray &tnef,
-        const KCalendarCore::MemoryCalendar::Ptr &cal,
-        KCalUtils::InvitationFormatterHelper *h);
+                                                            const KCalendarCore::MemoryCalendar::Ptr &cal,
+                                                            KCalUtils::InvitationFormatterHelper *h);
 
 /**
     Transforms a @acronym TNEF attachment to an iCal or vCard.
